@@ -1,6 +1,6 @@
 ###            Fit a general nonlinear mixed effects model
 ###
-### Copyright 2006-2018 The R Core team
+### Copyright 2006-2021  The R Core team
 ### Copyright 1997-2003  Jose C. Pinheiro,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
 ###
@@ -104,7 +104,7 @@ nlme.nlsList <-
       mData <- eval(alist, sys.parent(1))
     }
   } else if (mode(mData) == "name" || mode(mData) == "call") {
-    mData <- eval(mData)
+    mData <- eval.parent(mData)
   }
   reSt <- reStruct(random, REML = REML, data = mData)
   names(reSt) <- deparse(groups[[2]])
@@ -123,7 +123,7 @@ nlme.nlsList <-
   }
   thisCall[["start"]] <- start
   thisCall[["random"]] <- reSt
-  val <- do.call(nlme.formula, thisCall)
+  val <- do.call(nlme.formula, thisCall, envir = parent.frame())
   val$origCall <- match.call()
   val
 }
@@ -216,9 +216,8 @@ nlme.formula <-
   ##
   if (missing(start) && !is.null(attr(eval(model[[3]][[1]]), "initial"))) {
     nlmeCall <- Call
-    nlsLCall <- nlmeCall[c("","model","data","groups")]
+    nlsLCall <- nlmeCall[c("","model","data")]
     nlsLCall[[1]] <- quote(nlme::nlsList)
-    names(nlsLCall)[2] <- "model"
     nm <- names(nlmeCall)
     for(i in c("fixed", "data", "groups", "start"))
       if(i %in% nm) nlmeCall[[i]] <- NULL
@@ -227,11 +226,9 @@ nlme.formula <-
     if (is.null(dim(data))) {
       stop("'data' must be given explicitly to use 'nlsList'")
     }
-    nlsLObj <- eval(nlsLCall)
-    nlsLObj # -NOTE(codetools)
-    nlmeCall[["model"]] <- quote(nlsLObj)
-    nlmeCall <- as.call(nlmeCall)
-    val <- eval(nlmeCall)
+    nlsLObj <- eval.parent(nlsLCall)
+    nlmeCall[["model"]] <- nlsLObj
+    val <- eval.parent(nlmeCall)
     val$origCall <- NULL
     return(val)
   }
@@ -519,7 +516,7 @@ nlme.formula <-
       nm <- rnames[[i]][j]
       wchRnames[[i]][nm] <- wchRnames[[i]][nm] + 1
       r <- plist[[nm]]$random[[i]]
-      if (data.class(r) == "list") r <- r[[wchRnames[[i]][nm]]]
+      if(is.list(r)) r <- r[[wchRnames[[i]][nm]]]
       if (is.logical(r)) {
         if (r) {
           rn[[i]] <- c(rn[[i]],
@@ -656,9 +653,7 @@ nlme.formula <-
     for(nm in rnames[[i]]) {
       wchRnames[[i]][nm] <- wchRnames[[i]][nm] + 1
       r <- plist[[nm]]$random[[i]]
-      if (data.class(r) == "list") {
-        r <- r[[wchRnames[[i]][nm]]]
-      }
+      if(is.list(r)) r <- r[[wchRnames[[i]][nm]]]
       if (is.logical(r)) {
         val <- n1
         n1 <- n1 + 1
@@ -723,7 +718,7 @@ nlme.formula <-
             Z[, rmap[[i]][[nm]]] <- gradnm  # else r == FALSE =^= 0
         } else {
           rm.i <- rmap[[i]][[nm]]
-          if (data.class(rm.i) != "list") {
+          if (!is.list(rm.i)) {
             Z[, rm.i] <- gradnm * r
           } else {
             for(j in seq_along(rm.i)) {
@@ -1059,7 +1054,7 @@ getParsNlme <-
           if (r)
             pars[, nm] <- pars[, nm] + b.i[rm.i., gr.i]
           ## else r == FALSE =^= 0
-        } else if (data.class(r) != "list") {
+        } else if (!is.list(r)) {
           pars[, nm] <- pars[, nm] +
             (r * t(b.i)[gr.i, rm.i., drop=FALSE]) %*% rep(1, ncol(r))
         } else {
