@@ -2,7 +2,7 @@
    header file for the nlme package
 
    Copyright 1999-2001  Saikat DebRoy
-   Copyright 2007-2013  The R Core Team
+   Copyright 2007-2016  The R Core Team
 
    This file is part of the nlme package for S and related languages
    and is made available under the terms of the GNU General Public
@@ -31,25 +31,23 @@ int F77_NAME(rs)(int *nm, int *n, double *a, double *w,
 
 typedef struct QR_struct {
   double *mat, *qraux;
-  longint *pivot, rank, ldmat, nrow, ncol;
+  int *pivot, rank, ldmat, nrow, ncol;
 } *QRptr;
 
-extern void d_axpy(double *, double, double *, longint);
-extern double d_dot_prod(double *, longint, double *, longint, longint);
-extern double d_sum_sqr( double *, longint);
-extern double *copy_mat(double *, longint, double *, longint, longint,
-			longint);
-extern double *copy_trans(double *, longint, double *, longint,
-			  longint, longint);
-extern double *mult_mat(double *, longint, double *, longint, longint,
-			longint, double *, longint, longint);
-extern QRptr QR(double *, longint, longint, longint);
+extern void d_axpy(double *, double, double *, int);
+extern double d_dot_prod(double *, int, double *, int, int);
+extern double d_sum_sqr( double *, int);
+extern double *copy_mat(double *, int, double *, int, int, int);
+extern double *copy_trans(double *, int, double *, int, int, int);
+extern double *mult_mat(double *, int, double *, int, int, int, double *,
+			int, int);
+extern QRptr QR(double *, int, int, int);
 extern void QRfree(QRptr);
-extern longint QRqty(QRptr, double *, longint, longint);
-extern longint QRsolve(QRptr, double *, longint, longint, double *, longint);
+extern int QRqty(QRptr, double *, int, int);
+extern int QRsolve(QRptr, double *, int, int, double *, int);
 extern double QRlogAbsDet(QRptr);
-extern void QRstoreR(QRptr, double *, longint);
-extern longint QR_and_rotate(double *, longint, longint, longint,
-			     double *, longint, longint, double *,
-			     double *, longint);
+extern void QRstoreR(QRptr, double *, int);
+extern int QR_and_rotate(double *, int, int, int,
+			 double *, int, int, double *,
+			 double *, int);
 #endif /* NLME_MATRIX_H */
